<?php
  /**
 * This file is part of a project maintained at  NC State University.
 *
 * More information is included in the project README.md.
 *
 * (c) NC State University
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace NCSU\Auth\Adapter;

use Exception;
use NCSU\Auth\AuthResult;
use NCSU\Auth\Exception\InvalidArgumentException;
use NCSU\Auth\Exception\RuntimeException;
use NCSU\Auth\Http\Request;

/**
 * Authentication adapter testing authentication. Statically assigns
 * the authenticated identity.
 *
 * @author Dustin Wheeler <mdwheele@ncsu.edu>
 */
final class MockAuthAdapter implements AdapterInterface
{
    protected $identity;

    public function __construct($identity)
    {
        if (empty($identity)) {
            throw new InvalidArgumentException("Identity must be provided when using MockAuthAdapter.");
        }

        $this->identity = $identity;
    }

    /**
     * Attempts to authenticate.
     *
     * @throws RuntimeException
     * @return \NCSU\Auth\AuthResult
     */
    public function authenticate()
    {
        return new AuthResult(AuthResult::SUCCESS, $this->identity);
    }
}