<?php
  /**
 * This file is part of a project maintained at  NC State University.
 *
 * More information is included in the project README.md.
 *
 * (c) NC State University
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace NCSU\Auth\Http;

/**
 * A class representing an HTTP request.
 *
 * @author Dustin Wheeler <mdwheele@ncsu.edu>
 */
class Request 
{
    /**
     * $_GET
     * @var array
     */
    public $query;

    /**
     * $_POST
     * @var array
     */
    public $request;

    /**
     * $_COOKIE
     * @var array
     */
    public $cookies;

    /**
     * $_FILES
     * @var array
     */
    public $files;

    /**
     * $_SERVER
     * @var array
     */
    public $server;

    /**
     * @param array $query   The GET parameters
     * @param array $request The POST parameters
     * @param array $cookies The COOKIE parameters
     * @param array $files   The FILES parameters
     * @param array $server  The SERVER parameters
     */
    public function __construct(
        array $query = array(),
        array $request = array(),
        array $cookies = array(),
        array $files = array(),
        array $server = array()
    )
    {
        $this->query = $query;
        $this->request = $request;

        $this->cookies = $cookies;
        $this->files = $files;
        $this->server = $server;
    }

    /**
     * Creates a new Request object from PHP super globals.
     *
     * @return Request
     */
    public static function createFromGlobals()
    {
        return new Request($_GET, $_POST, $_COOKIE, $_FILES, $_SERVER);
    }

    public function setMethod($method)
    {
        $this->server['REQUEST_METHOD'] = $method;
    }

    public function getMethod()
    {
        return $this->server['REQUEST_METHOD'];
    }

    public function getCurrentUri()
    {
        return sprintf(
            '%s%s',
            $this->getHost(),
            $this->server['REQUEST_URI']
        );
    }

    public function getHost()
    {
        return sprintf(
            'http%s://%s',
            (empty($this->server['HTTPS']) ? '' : 's'),
            $this->server['SERVER_NAME']
        );
    }
} 
