<?php

namespace NCSU\Auth\Adapter;

use NCSU\Auth\Adapter\WrapAuthAdapter;
use NCSU\Auth\Http\Request;

class ShibAuthAdapterTest extends \PHPUnit_Framework_TestCase
{
    /** @test */
    public function it_should_return_valid_auth_result_after_user_has_authenticated()
    {
        $this->beShibbolethUser('cacard');

        $adapter = new ShibAuthAdapter(Request::createFromGlobals());
        $result = $adapter->authenticate();

        $this->assertInstanceOf('\NCSU\Auth\AuthResult', $result);
        $this->assertTrue($result->isValid());
        $this->assertEquals('cacard', $result->getIdentity());
    }

    /** @test */
    public function it_should_return_invalid_auth_result_when_user_is_not_authenticated()
    {
        $this->beShibbolethUser('');

        $adapter = new ShibAuthAdapter(Request::createFromGlobals());
        $result = $adapter->authenticate();

        $this->assertFalse($result->isValid());
    }

    private function beShibbolethUser($userId)
    {
        $_SERVER['Shib-Session-ID'] = 'foo';
        $_SERVER['SHIB_UID'] = $userId;
    }
}
